import 'package:flutter/material.dart';

typedef ActionTap = Future<void> Function();


/// 当autoPop为ture的时候，如果需要在回调中跳转另外一个页面
/// 请按照下面代码操作，否则会出现跳转失败的情况
/// ```
/// Future.delayed(Duration(seconds: 0)).then((value) => Navigator.of(context).push(
///                   MaterialPageRoute(
///                     builder: (context) => Scaffold(
///                       appBar: AppBar(
///                         title: Text("aaa"),
///                       ),
///                       body: Container(),
///                     ),
///                   ),
///                 ));
///```

class PQBottomSheetAction<T> {
  /// 文本
  final String? text;

  /// 背景色
  final Color? color;

  /// 文本颜色
  final Color? textColor;

  /// 文本大小
  final double? fontSize;

  /// 文字字重
  final FontWeight? fontWeight;

  /// 点击事件
  final ActionTap? onTap;
  final T? Function(PQBottomSheetAction model)? result;

  /// 分割线颜色 default is `Color(0xFFF0F0F0)1
  final Color dividerLineColor;

  ///
  final EdgeInsetsGeometry? padding;

  ///
  final EdgeInsetsGeometry? margin;

  /// 是否自动消失，默认是true
  final bool autoPop;

  final int? maxLines;

  PQBottomSheetAction._(
    this.text, {
    this.color,
    this.textColor,
    this.fontWeight,
    this.fontSize,
    this.onTap,
    this.result,
    this.padding,
    this.margin,
        this.maxLines,
    this.autoPop = true,
    this.dividerLineColor = const Color(0xFFF0F0F0),
  });

  factory PQBottomSheetAction.custom(String? text,
          {Color? color,
          Color? textColor,
          FontWeight? fontWeight,
          double? fontSize,
          ActionTap? onTap,
          EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
          EdgeInsetsGeometry? margin = const EdgeInsets.only(),
          bool autoPop = true,
          Color? dividerLineColor,
            int? maxLines,
          T? Function(PQBottomSheetAction model)? result}) =>
      PQBottomSheetAction._(text,
          color: color,
          textColor: textColor,
          fontWeight: fontWeight,
          fontSize: fontSize,
          onTap: onTap,
          padding: padding,
          margin: margin,
          autoPop: autoPop,
          dividerLineColor: dividerLineColor ?? Color(0xFFF0F0F0),
          maxLines: maxLines,
          result: result);

  factory PQBottomSheetAction.normal(String? text,
          {Color? color = Colors.transparent,
          Color? textColor = const Color(0xFF666666),
          double? fontSize,
          FontWeight? fontWeight = FontWeight.normal,
          ActionTap? onTap,
          EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
            EdgeInsetsGeometry? margin = const EdgeInsets.only(),
          bool autoPop = true,
          Color? dividerLineColor,
            int? maxLines,
          T? Function(PQBottomSheetAction model)? result}) =>
      PQBottomSheetAction._(text,
          color: color,
          textColor: textColor,
          fontWeight: fontWeight,
          fontSize: fontSize,
          onTap: onTap,
          padding: padding,
          margin: margin,
          autoPop: autoPop,
          dividerLineColor: dividerLineColor ?? Color(0xFFF0F0F0),
          maxLines: maxLines,
          result: result);

  factory PQBottomSheetAction.highlight(String? text,
          {Color? color = Colors.transparent,
          Color? textColor = const Color(0xFFF25555),
          double? fontSize,
          FontWeight? fontWeight = FontWeight.normal,
          ActionTap? onTap,
          EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
            EdgeInsetsGeometry? margin = const EdgeInsets.only(),
          bool autoPop = true,
          Color? dividerLineColor,
            int? maxLines,
          T? Function(PQBottomSheetAction model)? result}) =>
      PQBottomSheetAction._(text,
          color: color,
          textColor: textColor,
          fontWeight: fontWeight,
          fontSize: fontSize,
          onTap: onTap,
          padding: padding,
          margin: margin,
          autoPop: autoPop,
          dividerLineColor: dividerLineColor ?? Color(0xFFF0F0F0),
          maxLines: maxLines,
          result: result);

  factory PQBottomSheetAction.cancel(
          {String? text = "取消",
          Color? color = Colors.transparent,
          Color? textColor = const Color(0xFF666666),
          double? fontSize,
          FontWeight? fontWeight = FontWeight.normal,
          ActionTap? onTap,
          EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
          bool autoPop = true,
          Color? dividerLineColor,
            int? maxLines,
          T? Function(PQBottomSheetAction model)? result}) =>
      PQBottomSheetAction._(text,
          color: color,
          textColor: textColor,
          fontWeight: fontWeight,
          fontSize: fontSize,
          onTap: onTap,
          padding: padding,
          autoPop: autoPop,
          dividerLineColor: dividerLineColor ?? Colors.transparent,
          maxLines: maxLines,
          result: result);
}
